import {Component, OnInit} from '@angular/core';
import {ApiService} from '../../services/api.service';
import {UtilsService} from '../../services/utils.service';
import {Event} from '../../models/event';

@Component({
	selector: 'app-admin',
	templateUrl: './admin.component.html',
	styleUrls: ['./admin.component.css']
})
export class AdminComponent implements OnInit {

	isLoggedIn: boolean = false;
	events: Event[] = [];
	selectedCalendar: string = '';
	password: string = '';
	name: string = '';
	constructor(
		private api: ApiService
	) {
	}

	ngOnInit(): void {
		if (UtilsService.getPasswordFromLocalStorage() !== '') {
			this.isLoggedIn = true;
			this.getEvents();
		}
	}

	getEvents(): void {
		if(this.selectedCalendar === '') {
			return;
		}

		this.api.getEvents(this.selectedCalendar).subscribe((events: Event[]): void => {
			events.forEach((event: Event) => {
				this.events.push({
					...event,
					startDateTime: new Date(event.startDateTime),
					endDateTime: new Date(event.endDateTime),
					createdDate: new Date(event.createdDate)
				})
			})
		})
	}

	login(): void {
		UtilsService.saveUserInfoToLocalStorage(this.password, this.name);
		this.isLoggedIn = true;
		this.getEvents();
	}

	handleCalendarChange() {
		this.events = [];
		this.getEvents();
	}

	getCalendarId(text: string): number {
		switch(text) {
			case 'public':
				return 1;
			case 'members':
				return 2;
			case 'management':
				return 3;
			default:
				return -1;
		}
	}
}
